@@ -68,7 +68,7 @@ typedef struct
   
   /* Autocompletion */
   GCompletion      *completion;
-  gint              n_complete;
+  guint             n_complete;
 
   /* Properties */ 
   gint              size;
@@ -123,19 +123,14 @@ verve_plugin_load_completion (VerveEnv* env, gpointer user_data)
 }
 
 
-  
-static gboolean
+
+G_GNUC_UNUSED static gboolean
 verve_plugin_focus_timeout (gpointer user_data)
 {
   VervePlugin *verve = user_data;
-  GtkStyle *style;
-  GdkColor c;
-  
+
   g_return_val_if_fail (verve->input != NULL || GTK_IS_ENTRY (verve->input), FALSE);
-  
-  /* Determine current entry style */
-  style = gtk_widget_get_style (verve->input);
-  
+
   return TRUE;
 }
 
@@ -144,9 +139,6 @@ verve_plugin_focus_timeout (gpointer user_data)
 static void
 verve_plugin_focus_timeout_reset (VervePlugin *verve)
 {
-  GtkStyle *style;
-  GdkColor c;
-
   g_return_if_fail (verve != NULL);
   g_return_if_fail (verve->input != NULL || GTK_IS_ENTRY (verve->input));
 
@@ -160,6 +152,24 @@ verve_plugin_focus_timeout_reset (VervePlugin *verve)
 
 
 
+static gboolean
+verve_plugin_focus_in (GtkWidget *entry,
+                       GdkEventFocus *event,
+                       VervePlugin *verve)
+{
+  g_return_val_if_fail (verve != NULL, FALSE);
+  g_return_val_if_fail (verve->input != NULL || GTK_IS_ENTRY (verve->input), FALSE);
+
+#if !LIBXFCE4PANEL_CHECK_VERSION (4, 18, 5)
+  /* Unhide the panel */
+  xfce_panel_plugin_block_autohide (verve->plugin, TRUE);
+#endif
+
+  return FALSE;
+}
+
+
+
 static gboolean
 verve_plugin_focus_out (GtkWidget *entry,
                         GdkEventFocus *event,
@@ -171,7 +181,12 @@ verve_plugin_focus_out (GtkWidget *entry,
   /* Stop blinking */
   verve_plugin_focus_timeout_reset (verve);
 
-  return TRUE;
+#if !LIBXFCE4PANEL_CHECK_VERSION (4, 18, 5)
+  /* Hide the panel again */
+  xfce_panel_plugin_block_autohide (verve->plugin, FALSE);
+#endif
+
+  return FALSE;
 }
 
 
@@ -217,9 +232,6 @@ verve_plugin_grab_focus (VerveDBusService *dbus_service,
 
   if (toplevel && toplevel->window)
     {
-      /* Unhide the panel */
-      xfce_panel_plugin_block_autohide (verve->plugin, TRUE);
-
       /* Focus the command entry */
       xfce_panel_plugin_focus_widget (verve->plugin, verve->input);
       
@@ -243,9 +255,8 @@ verve_plugin_keypress_cb (GtkWidget   *entry,
   const gchar *prefix;
   GList       *similar = NULL;
   gboolean     selected = FALSE;
-  gint         selstart;
-  gint         i;
-  gint         len;
+  gint         selstart, len;
+  guint        i;
 
   g_return_val_if_fail (verve != NULL, FALSE);
 
@@ -363,9 +374,6 @@ verve_plugin_keypress_cb (GtkWidget   *entry,
         /* Try executing the command */
         if (G_LIKELY (verve_execute (command, terminal, verve->launch_params)))
           {
-            /* Hide the panel again */
-            xfce_panel_plugin_block_autohide (verve->plugin, FALSE);
-
             /* Do not add command to history if it is the same as the one before */
             if (verve_history_is_empty () || g_utf8_collate (verve_history_get_last_command (), command) != 0)
               {
@@ -451,7 +459,7 @@ verve_plugin_keypress_cb (GtkWidget   *entry,
                   verve->n_complete = 0;
 
                 /* Search the next result */
-                for (i=0; i<verve->n_complete; i++)
+                for (i = 0; i < verve->n_complete; i++)
                   if (similar->next != NULL)
                     similar = similar->next;
               }
@@ -479,6 +487,9 @@ verve_plugin_keypress_cb (GtkWidget   *entry,
 static VervePlugin*
 verve_plugin_new (XfcePanelPlugin *plugin)
 {
+  VervePlugin *verve;
+  GtkWidget   *hbox;
+
   /* Set application name */
   g_set_application_name ("Verve");
 
@@ -491,7 +502,7 @@ verve_plugin_new (XfcePanelPlugin *plugin)
   verve_init ();
   
   /* Create the plugin object */
-  VervePlugin *verve = g_new (VervePlugin, 1);
+  verve = g_new (VervePlugin, 1);
 
   /* Assign the panel plugin to the plugin member */
   verve->plugin = plugin;
@@ -526,7 +537,7 @@ verve_plugin_new (XfcePanelPlugin *plugin)
   gtk_widget_show (verve->event_box);
   
   /* Create a container for the label and input */
-  GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_container_add (GTK_CONTAINER (verve->event_box), hbox);
   gtk_widget_show (hbox);
 
@@ -547,6 +558,7 @@ verve_plugin_new (XfcePanelPlugin *plugin)
   /* Handle mouse button and key press events */
   g_signal_connect (verve->input, "key-press-event", G_CALLBACK (verve_plugin_keypress_cb), verve);
   g_signal_connect (verve->input, "button-press-event", G_CALLBACK (verve_plugin_buttonpress_cb), verve);
+  g_signal_connect (verve->input, "focus-in-event", G_CALLBACK (verve_plugin_focus_in), verve);
   g_signal_connect (verve->input, "focus-out-event", G_CALLBACK (verve_plugin_focus_out), verve);
 
 #ifdef HAVE_DBUS
@@ -652,12 +664,16 @@ verve_plugin_update_colors (XfcePanelPlugin *plugin,
                             const gchar     *base_color_str,
                             VervePlugin     *verve)
 {
+  GFileIOStream *tmp_file_stream;
+  GFile *tmp_file;
+  GIOStream *iostream;
+  GOutputStream *output_stream;
+
   g_return_val_if_fail (verve != NULL, FALSE);
 
-  GFileIOStream *tmp_file_stream;
-  GFile *tmp_file = g_file_new_tmp (NULL, &tmp_file_stream, NULL);
-  GIOStream *iostream = G_IO_STREAM (tmp_file_stream);
-  GOutputStream *output_stream = g_io_stream_get_output_stream (iostream);
+  tmp_file = g_file_new_tmp (NULL, &tmp_file_stream, NULL);
+  iostream = G_IO_STREAM (tmp_file_stream);
+  output_stream = g_io_stream_get_output_stream (iostream);
 
   // Write CSS to temporary file
   write_string (output_stream, "*{color:", "");
@@ -748,6 +764,9 @@ verve_plugin_read_rc_file (XfcePanelPlugin *plugin,
   const gchar *bg_color_str = "";
   const gchar *base_color_str = "";
 
+  /* Default search engine URL */
+  const gchar *smartbookmark_url = "";
+
   /* Default number of saved history entries */
   gint    history_length = 25;
 
@@ -761,9 +780,6 @@ verve_plugin_read_rc_file (XfcePanelPlugin *plugin,
   verve->launch_params.use_smartbookmark = FALSE;
   verve->launch_params.use_shell = TRUE;
 
-  /* Default search engine URL */
-  const gchar *smartbookmark_url = "";
-
   g_return_if_fail (plugin != NULL);
   g_return_if_fail (verve != NULL);
 
@@ -907,12 +923,14 @@ static void
 verve_plugin_fg_color_changed (GtkColorButton *color_button, 
                                VervePlugin *verve)
 {
+  GdkRGBA  color;
+  gchar   *color_str;
+
   g_return_if_fail (verve != NULL);
 
   /* Get the entered color */
-  GdkRGBA color;
   gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER(color_button), &color);
-  gchar *color_str = gdk_rgba_to_string (&color);
+  color_str = gdk_rgba_to_string (&color);
 
   verve_plugin_update_colors (NULL, color_str, NULL, NULL, verve);
 
@@ -925,12 +943,14 @@ static void
 verve_plugin_base_color_changed (GtkColorButton *color_button, 
                                  VervePlugin *verve)
 {
+  GdkRGBA  color;
+  gchar   *color_str;
+
   g_return_if_fail (verve != NULL);
 
   /* Get the entered color */
-  GdkRGBA color;
   gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER(color_button), &color);
-  gchar *color_str = gdk_rgba_to_string (&color);
+  color_str = gdk_rgba_to_string (&color);
 
   verve_plugin_update_colors (NULL, NULL, NULL, color_str, verve);
 
@@ -945,11 +965,8 @@ verve_plugin_label_changed (GtkEntry *box,
 {
   g_return_if_fail (verve != NULL);
 
-  /* Get the entered URL */
-  const gchar *label = gtk_entry_get_text (box);
-
   /* Update search engine ID */
-  verve_plugin_update_label (NULL, label, verve);
+  verve_plugin_update_label (NULL, gtk_entry_get_text (box), verve);
 }
 
 
@@ -1052,11 +1069,8 @@ verve_plugin_smartbookmark_url_changed (GtkEntry    *box,
 {
   g_return_if_fail (verve != NULL);
 
-  /* Get the entered URL */
-  const gchar *smartbookmark_url = gtk_entry_get_text(box);
-
   /* Update search engine ID */
-  verve_plugin_update_smartbookmark_url (NULL, smartbookmark_url, verve);
+  verve_plugin_update_smartbookmark_url (NULL, gtk_entry_get_text (box), verve);
 }
 
 
@@ -1111,7 +1125,6 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   GtkAdjustment *adjustment;
 
   GtkWidget *bin3;
-  GtkWidget *alignment;
   GtkWidget *command_types_vbox;
   GtkWidget *command_types_label1;
   GtkWidget *command_types_label2;
@@ -1126,8 +1139,6 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   GtkWidget *command_type_executable;
   GtkWidget *command_type_use_shell;
 
-  gchar     *color_str;
-
   g_return_if_fail (plugin != NULL);
   g_return_if_fail (verve != NULL);
 
@@ -1135,11 +1146,11 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   xfce_panel_plugin_block_menu (plugin);
 
   /* Create properties dialog */
-  dialog = xfce_titled_dialog_new_with_buttons (_("Verve"),
-                                                GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
-                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
-                                                NULL);
+  dialog = xfce_titled_dialog_new_with_mixed_buttons (_("Verve"),
+                                                      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
+                                                      GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                      "window-close", _("_Close"), GTK_RESPONSE_OK,
+                                                      NULL);
 
   /* Set dialog property */
   g_object_set_data (G_OBJECT (plugin), "dialog", dialog);
@@ -1157,7 +1168,7 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), notebook, TRUE, TRUE, 0);
   gtk_widget_show (notebook);
   
-  general_vbox = gtk_vbox_new (FALSE, 8);
+  general_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
   notebook_tab_label_current = gtk_label_new (_("General"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), general_vbox, notebook_tab_label_current);
   gtk_widget_show(general_vbox);
@@ -1169,12 +1180,12 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_widget_show (frame);
 
   /* Appearance settings vertical container */
-  vbox = gtk_vbox_new (FALSE, 8);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
   gtk_container_add (GTK_CONTAINER(bin1), vbox);
   gtk_widget_show(vbox);
 
   /* Plugin size container */
-  hbox = gtk_hbox_new (FALSE, 8);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
@@ -1199,7 +1210,7 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   g_signal_connect (size_spin, "value-changed", G_CALLBACK (verve_plugin_size_changed), verve);
 
   /* Plugin label container */
-  hbox = gtk_hbox_new (FALSE, 8);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
@@ -1227,12 +1238,12 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_widget_show (frame);
 
   /* Color settings vertical container */
-  vbox = gtk_vbox_new (FALSE, 8);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
   gtk_container_add (GTK_CONTAINER(bin1), vbox);
   gtk_widget_show(vbox);
 
   /* Plugin background color container */
-  hbox = gtk_hbox_new (FALSE, 8);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
@@ -1248,7 +1259,7 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   if (verve->base_color_str) {
     GdkRGBA color;
     gdk_rgba_parse(&color, verve->base_color_str);
-    gtk_color_button_set_rgba(GTK_COLOR_BUTTON (base_color_box), &color);
+    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER (base_color_box), &color);
   }
   gtk_widget_add_mnemonic_label (base_color_box, base_color_label);
   gtk_box_pack_start (GTK_BOX (hbox), base_color_box, FALSE, TRUE, 0);
@@ -1258,7 +1269,7 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   g_signal_connect (base_color_box, "color-set", G_CALLBACK (verve_plugin_base_color_changed), verve);
 
   /* Plugin foreground color container */
-  hbox = gtk_hbox_new (FALSE, 8);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
@@ -1274,7 +1285,7 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   if (verve->fg_color_str) {
     GdkRGBA color;
     gdk_rgba_parse(&color, verve->fg_color_str);
-    gtk_color_button_set_rgba(GTK_COLOR_BUTTON (fg_color_box), &color);
+    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER (fg_color_box), &color);
   }
   gtk_widget_add_mnemonic_label (fg_color_box, fg_color_label);
   gtk_box_pack_start (GTK_BOX (hbox), fg_color_box, FALSE, TRUE, 0);
@@ -1290,12 +1301,12 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_widget_show (frame);
   
   /* Behaviour settings vertical container */
-  vbox = gtk_vbox_new (FALSE, 8);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
   gtk_container_add (GTK_CONTAINER(bin2), vbox);
   gtk_widget_show(vbox);
 
   /* Plugin history length container */
-  hbox = gtk_hbox_new (FALSE, 8);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
@@ -1328,13 +1339,13 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame, notebook_tab_label_current);
   gtk_widget_show (frame);
   
-  command_types_vbox = gtk_vbox_new (FALSE, 0);
+  command_types_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (bin3), command_types_vbox);
   gtk_widget_show (command_types_vbox);
 
   /* Pattern types frame label */
   command_types_label1 = gtk_label_new(_("Enable support for:"));
-  gtk_misc_set_alignment (GTK_MISC (command_types_label1), 0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (command_types_label1), 0);
   gtk_box_pack_start (GTK_BOX (command_types_vbox), command_types_label1, FALSE, TRUE, 8);
   gtk_widget_show (command_types_label1);
   
@@ -1363,13 +1374,9 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   g_signal_connect (command_type_dir, "toggled", G_CALLBACK (verve_plugin_use_dir_changed), verve);
 
   /* wordexp checkbox */
-  alignment = gtk_alignment_new (1, 1, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 24, 0);
-  gtk_box_pack_start (GTK_BOX (command_types_vbox), alignment, FALSE, TRUE, 0);
-  gtk_widget_show (alignment);
-  
   command_type_use_wordexp = gtk_check_button_new_with_label(_("Expand variables with wordexp"));
-  gtk_container_add (GTK_CONTAINER (alignment), command_type_use_wordexp);
+  gtk_widget_set_margin_start (command_type_use_wordexp, 24);
+  gtk_box_pack_start (GTK_BOX (command_types_vbox), command_type_use_wordexp, FALSE, TRUE, 0);
 #ifdef HAVE_WORDEXP
   gtk_widget_show (command_type_use_wordexp);
 #endif
@@ -1395,7 +1402,7 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   
   /* Fallback if the above don't match */
   command_types_label2 = gtk_label_new(_("If the above patterns don't match:"));
-  gtk_misc_set_alignment (GTK_MISC (command_types_label2), 0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (command_types_label2), 0);
   gtk_box_pack_start (GTK_BOX (command_types_vbox), command_types_label2, FALSE, TRUE, 8);
   gtk_widget_show (command_types_label2);
   
@@ -1409,11 +1416,10 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
 
   /* Smart bookmark entry box */
   engine_box = gtk_entry_new();
-  alignment = gtk_alignment_new (1, 1, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 8, 8, 24, 0);
-  gtk_box_pack_start (GTK_BOX (command_types_vbox), alignment, FALSE, TRUE, 0);
-  gtk_widget_show (alignment);
-  gtk_container_add (GTK_CONTAINER (alignment), engine_box);
+  gtk_widget_set_margin_start (engine_box, 24);
+  gtk_widget_set_margin_top (engine_box, 8);
+  gtk_widget_set_margin_bottom (engine_box, 8);
+  gtk_box_pack_start (GTK_BOX (command_types_vbox), engine_box, FALSE, TRUE, 0);
   gtk_widget_show (engine_box);
 
   /* Set text to search engine URL */
@@ -1430,13 +1436,9 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (command_type_executable), !verve->launch_params.use_smartbookmark);
 
   /* Use shell checkbox */
-  alignment = gtk_alignment_new (1, 1, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 24, 0);
-  gtk_box_pack_start (GTK_BOX (command_types_vbox), alignment, FALSE, TRUE, 0);
-  gtk_widget_show (alignment);
-  
   command_type_use_shell = gtk_check_button_new_with_label(_("Run command with $SHELL -i -c\n(enables alias and variable expansion)"));
-  gtk_container_add (GTK_CONTAINER (alignment), command_type_use_shell);
+  gtk_widget_set_margin_start (command_type_use_shell, 24);
+  gtk_box_pack_start (GTK_BOX (command_types_vbox), command_type_use_shell, FALSE, TRUE, 0);
   gtk_widget_show (command_type_use_shell);
   
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (command_type_use_shell), verve->launch_params.use_shell);
@@ -1452,11 +1454,13 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
 static void
 verve_plugin_construct (XfcePanelPlugin *plugin)
 {
+  VervePlugin *verve;
+
   /* Set gettext text domain */
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
   
   /* Create Verve plugin */
-  VervePlugin *verve = verve_plugin_new (plugin);
+  verve = verve_plugin_new (plugin);
 
   /* Read config file */
   verve_plugin_read_rc_file (plugin, verve);
