@@ -21,9 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
-#include <pcre.h>
+/* allows using generic function names instead of suffixing them with _8 */
+#define PCRE2_CODE_UNIT_WIDTH 8
+#include <pcre2.h>
 
 #include <glib-object.h>
 
@@ -39,22 +43,22 @@
 
 
 
-static gboolean verve_is_url       (const gchar *str);
-static gboolean verve_is_email     (const gchar *str);
+static gboolean verve_is_url       (PCRE2_SPTR str);
+static gboolean verve_is_email     (PCRE2_SPTR str);
 static gchar *verve_is_directory   (const gchar *str, gboolean use_wordexp);
 
 
 
-/* URL/eMail matching patterns */
+/* URL/email matching patterns */
 #define USERCHARS   "-A-Za-z0-9"
 #define PASSCHARS   "-A-Za-z0-9,?;.:/!%$^*&~\"#'"
 #define HOSTCHARS   "-A-Za-z0-9"
-#define USER        "[" USERCHARS "]+(:["PASSCHARS "]+)?"
-#define MATCH_URL1  "^((file|https?|ftps?)://(" USER "@)?)[" HOSTCHARS ".]+(:[0-9]+)?" \
-                    "(/[-A-Za-z0-9_$.+!*(),;:@&=?/~#%]*[^]'.}>) \t\r\n,\\\"])?/?$"
-#define MATCH_URL2  "^(www|ftp)[" HOSTCHARS "]*\\.[" HOSTCHARS ".]+(:[0-9]+)?" \
-                    "(/[-A-Za-z0-9_$.+!*(),;:@&=?/~#%]*[^]'.}>) \t\r\n,\\\"])?/?$"
-#define MATCH_EMAIL "^(mailto:)?[a-z0-9][a-z0-9.-]*@[a-z0-9][a-z0-9-]*(\\.[a-z0-9][a-z0-9-]*)+$"
+#define USER        "[" USERCHARS "]+(?::["PASSCHARS "]+)?"
+#define MATCH_URL1  "^(?:(?:file|https?|ftps?)://(?:" USER "@)?)[" HOSTCHARS ".]+(?::[0-9]+)?" \
+                    "(?:/[-A-Za-z0-9_$.+!*(),;:@&=?/~#%]*[^]'.}>) \t\r\n,\\\"])?/?$"
+#define MATCH_URL2  "^(?:www|ftp)[" HOSTCHARS "]*\\.[" HOSTCHARS ".]+(?::[0-9]+)?" \
+                    "(?:/[-A-Za-z0-9_$.+!*(),;:@&=?/~#%]*[^]'.}>) \t\r\n,\\\"])?/?$"
+#define MATCH_EMAIL "^(?:mailto:)?[a-z0-9][a-z0-9.-]*@[a-z0-9][a-z0-9-]*(?:\\.[a-z0-9][a-z0-9-]*)+$"
 
 /*********************************************************************
  *
@@ -122,19 +126,12 @@ gboolean verve_spawn_command_line (const gchar *cmdline)
   gchar      **argv;
   gboolean     success;
   GPid         child_pid;
-  GError      *error = NULL;
   const gchar *home_dir;
   GSpawnFlags  flags;
-  
-  /* Parse command line arguments */
-  success = g_shell_parse_argv (cmdline, &argc, &argv, &error);
 
-  /* Return false if command line arguments failed to be arsed */
-  if (G_UNLIKELY (error != NULL))
-    {
-      g_error_free (error);
-      return FALSE;
-    }
+  /* Return false if command line arguments failed to be parsed */
+  if (G_UNLIKELY (!g_shell_parse_argv (cmdline, &argc, &argv, NULL)))
+    return FALSE;
 
   /* Get user's home directory */
   home_dir = xfce_get_homedir ();
@@ -146,19 +143,10 @@ gboolean verve_spawn_command_line (const gchar *cmdline)
   flags |= G_SPAWN_DO_NOT_REAP_CHILD;
   
   /* Spawn subprocess */
-  success = g_spawn_async (home_dir, argv, NULL, flags, verve_setsid, NULL, &child_pid, &error);
-
-  /* Return false if subprocess could not be spawned */
-  if (G_UNLIKELY (error != NULL)) 
-    {
-      g_error_free (error);
-      return FALSE;
-    }
-
-  /* Free command line arguments */
+  success = g_spawn_async (home_dir, argv, NULL, flags, verve_setsid, NULL, &child_pid, NULL);
   g_strfreev (argv);
-
-  g_child_watch_add(child_pid, verve_command_callback, NULL);
+  if (G_LIKELY (success))
+    g_child_watch_add (child_pid, verve_command_callback, NULL);
 
   /* Return whether process was spawned successfully */
   return success;
@@ -172,7 +160,7 @@ gboolean verve_spawn_command_line (const gchar *cmdline)
  * ---------------------------
  *
  * This method should be used whenever you want to run command line 
- * input, be it a URL, an eMail address or a custom command.
+ * input, be it a URL, an email address or a custom command.
  *
  *********************************************************************/
 
@@ -185,8 +173,8 @@ verve_execute (const gchar *input,
   gchar   *directory_exp;
   gboolean result = FALSE;
     
-  /* Open URLs, eMail addresses and directories using exo-open */
-  if ((launch_params.use_email && verve_is_email (input)) || (launch_params.use_url && verve_is_url (input)))
+  /* Open URLs, email addresses and directories using exo-open */
+  if ((launch_params.use_email && verve_is_email ((PCRE2_SPTR) input)) || (launch_params.use_url && verve_is_url ((PCRE2_SPTR) input)))
   {
     /* Build exo-open command */
     command = g_strconcat ("exo-open ", input, NULL);
@@ -215,11 +203,13 @@ verve_execute (const gchar *input,
   {
     if (launch_params.use_shell)
     {
+      gchar *shell, *quoted_input;
+
       /* Find current shell */
-      char *shell = getenv("SHELL");
+      shell = getenv("SHELL");
       if (shell == NULL) shell = "/bin/sh";
-      
-      gchar *quoted_input = g_shell_quote (input);
+
+      quoted_input = g_shell_quote (input);
       command = g_strconcat (shell, " -i -c ", quoted_input, NULL);
       g_free (quoted_input);
     }
@@ -259,77 +249,50 @@ verve_execute (const gchar *input,
  *
  *********************************************************************/
 
-gboolean
-verve_is_url (const gchar *str)
+static gboolean
+verve_is_pattern (PCRE2_SPTR str,
+                  PCRE2_SPTR pattern)
 {
-  GString     *string = g_string_new (str);
-  pcre        *pattern;
-  const gchar *error;
-  int          error_offset;
-  int          ovector[30];
-  gboolean     success = FALSE;
+  pcre2_code       *re;
+  int               errorcode;
+  PCRE2_SIZE        erroroffset;
+  pcre2_match_data *match_data;
+  gboolean          success = FALSE;
 
-  /* Compile first pattern */
-  pattern = pcre_compile (MATCH_URL1, 0, &error, &error_offset, NULL);
-  
-  /* Test whether the string matches this pattern */
-  if (pcre_exec (pattern, NULL, string->str, string->len, 0, 0, ovector, 30) >= 0)
-    success = TRUE;
-
-  /* Free pattern */
-  pcre_free (pattern);
-
-  /* Free data and return true if string matched the first pattern */
-  if (success)
+  /* Compile pattern */
+  re = pcre2_compile (pattern, PCRE2_ZERO_TERMINATED, 0, &errorcode, &erroroffset, NULL);
+  if (re != NULL)
+  {
+    match_data = pcre2_match_data_create_from_pattern (re, NULL);
+    if (match_data != NULL)
     {
-      g_string_free (string, TRUE);
-      return TRUE;
+      /* Test whether the string matches this pattern */
+      success = (pcre2_match (re, str, PCRE2_ZERO_TERMINATED, 0, 0, match_data, NULL) >= 0);
+      pcre2_match_data_free (match_data);
     }
+    pcre2_code_free (re);
+  }
 
-  /* Compile second pattern */
-  pattern = pcre_compile (MATCH_URL2, 0, &error, &error_offset, NULL);
-
-  /* Test whether the string matches this pattern */
-  if (pcre_exec (pattern, NULL, string->str, string->len, 0, 0, ovector, 30) >= 0)
-    success = TRUE;
-
-  /* Free pattern */
-  pcre_free (pattern);
-
-  /* Free string */
-  g_string_free (string, TRUE);
-
-  /* Return whether the string matched any of the URL patterns */
   return success;
 }
 
+gboolean
+verve_is_url (PCRE2_SPTR str)
+{
+  if (verve_is_pattern (str, (PCRE2_SPTR) MATCH_URL1))
+    return TRUE;
+  if (verve_is_pattern (str, (PCRE2_SPTR) MATCH_URL2))
+    return TRUE;
+
+  return FALSE;
+}
+
 
 
 gboolean
-verve_is_email (const gchar *str)
+verve_is_email (PCRE2_SPTR str)
 {
-  GString     *string = g_string_new (str);
-  const gchar *error;
-  pcre        *pattern;
-  int          error_offset;
-  int          ovector[30];
-  gboolean     success = FALSE;
-
-  /* Compile the pattern */
-  pattern = pcre_compile (MATCH_EMAIL, 0, &error, &error_offset, NULL);
-
-  /* Test whether the string matches this pattern */
-  if (pcre_exec (pattern, NULL, string->str, string->len, 0, 0, ovector, 30) >= 0)
-    success = TRUE;
-
-  /* Free pattern */
-  pcre_free (pattern);
-
-  /* Free string data */
-  g_string_free (string, TRUE);
-
-  /* Return whether the string matched any of the eMail patterns */
-  return success;
+  return verve_is_pattern (str, (PCRE2_SPTR) MATCH_EMAIL);
 }
 
 
